--------------------------------------------------------------------------------------------------------------
--
-- Module     : SIMS Database SQL Server 2005
-- Platform   : SIMS
-- Area       : DBUpgrade Database Patch
-- Copyright  : (c) Capita Education Services 2005-2009
--            : This code has been written by Capita Education Services for use within its own SIMS systems.
--            : It is unpublished proprietary work, and as such it is illegal for it to be reproduced by any
--            : means or used without the express written permission of Capita Education Services.
-- Patch ID   : 19328
--
--------------------------------------------------------------------------------------------------------------

-- Check this is within the acceptible range
  IF NOT EXISTS(
	SELECT 1 
	FROM	sims.db_version_info
	WHERE	schema_version BETWEEN '3.62.118' AND '3.64.999')
  BEGIN
    DECLARE @error_msg2 VARCHAR(100)
    SET @error_msg2 = CHAR(10) + CHAR(13) + 'This patch is not applicable to this database version.' + CHAR(10) + CHAR(13)
	raiserror(@error_msg2, 18, 1)
  END

GO
-- START PATCH CODE



-- START PATCH SCRIPT 1

/*
Sanitise telephone and email addresses on training data.
Reset all mobile numbers stored in SIMS to have the fictitious dialling code 07333 (which is reserved for TV\drama use)
Reset all non-mobile numbers (including fax numbers) in SIMS to have the fictitious area code 01632 (which is a reserved code for TV\drama use)
Reset all email addresses to be on the domain @example.com (which is reserved for examples\testing)

*/

--temp table to store school lea and school number for validation later
Declare @schoolDetails as table
(
	 LEA  varchar(3)
	,School_Number varchar(4)
)

Declare @LEA varchar(3)
        ,@School_number varchar(4)
       

--English Green Abbey (Secondary)
insert into @schoolDetails(LEA,School_Number)
select '823','4321' 

--English Waters Edge (Primary)
insert into @schoolDetails(LEA,School_Number)
select '823','2999' 

--Welsh Green Abbey (Secondary)
insert into @schoolDetails(LEA,School_Number)
select '674','4321' 

--Welsh Waters Edge (Primary) 
insert into @schoolDetails(LEA,School_Number)
select '674','2999' 

select  @LEA = lea_number
		,@School_number = school_number
from sims.sims_school where status = 'S'


IF not exists (select 1 from @schoolDetails where LEA = @LEA and School_Number = @School_number)
BEGIN
      Raiserror('This patch cannot be applied to this school',16,1)
      Return
END	
ELSE 
BEGIN

	--Reset all mobile numbers stored in SIMS to have the fictitious dialling code 07333 (which is reserved for TV\drama use)
	update te 
	set number =   REPLACE(REPLACE(REPLACE(number,' ',''),SUBSTRING(REPLACE(number,' ',''),1,5),'07333'),'07333','07333 ') 
	from sims.sims_telephone  te
	join sims.sims_telephone_location tl on tl.code = te.location
	join sims.sims_telephone_device td on td.code = te.device
	where  LEN(number) > 5  and tl.external_code = 'M' and td.external_code = 'T'

	--Reset all non-mobile numbers (including fax numbers) in SIMS to have the fictitious area code 01632 (which is a reserved code for TV\drama use)
	update te 
	set number = REPLACE(REPLACE(REPLACE(number,' ',''),SUBSTRING(REPLACE(number,' ',''),1,5),'01632'),'01632','01632 ') 
	from sims.sims_telephone  te
	join sims.sims_telephone_location tl on tl.code = te.location
	where  LEN(number) > 5  and tl.external_code <> 'M'

	--Reset all email addresses to be on the domain @example.com (which is reserved for examples\testing)
	update e
	set email_address =  REPLACE(email_address,SUBSTRING(email_address,PATINDEX('%@%.%',email_address),((LEN(email_address) + 1) - PATINDEX('%@%.%',email_address) )),'@example.com' )  
	from sims.sims_email e where e.email_id is not null 

END









-- END PATCH SCRIPT 1
GO


-- END PATCH CODE



-- Record that this patch has been updated
INSERT INTO sims.db_update_log
(
	patch_id,
	update_id,
	successful,
	description,
	update_type,
	date_applied
)
VALUES
(
	19328,
	1,
	'T',
	'INTERNAL ONLY Sanitise telephone and email addresses on training data.',
	'U',
	GetDate()
)

